"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @autor Olsi Rrjolli
 * This Class represent the controller registry.
 */
const MethodNotFoundError_1 = require("./exceptions/MethodNotFoundError");
const reflectMetadataHelpers_1 = require("./utils/reflectMetadataHelpers");
const MethodInformation_1 = require("./models/MethodInformation");
class ControllerRegistry {
    static register(controller) {
        this.controllersSet.add(controller);
    }
    /**
     * Scan the controller to find which method can execute for the request resource
     * @param requestEvent
     *  The aws request event
     * @returns {Controller}
     *  Get the correct Controller instance to execute the request command
     */
    static controllerScan(requestEvent) {
        let methodInformation;
        this.controllersSet.forEach((controllerClass) => {
            const controller = new controllerClass();
            console.log('Registered Controller: ', controller.constructor.name);
            console.log('Registered Methods: ', reflectMetadataHelpers_1.getControllerMetadata(controller));
            if (reflectMetadataHelpers_1.isMethodExistInController(requestEvent, controller)) {
                console.log('Selected Controller: ', controller.constructor.name);
                const methodName = reflectMetadataHelpers_1.getMethodName(requestEvent, controller);
                console.log('Selected Method: ', methodName);
                const toCallMethod = reflectMetadataHelpers_1.getMethod(controller, methodName);
                const args = reflectMetadataHelpers_1.parseArguments(requestEvent, methodName, controller);
                methodInformation = new MethodInformation_1.default();
                methodInformation.args = args;
                methodInformation.toCallMethod = toCallMethod;
                return;
            }
        });
        if (methodInformation) {
            return methodInformation;
        }
        const methodName = reflectMetadataHelpers_1.generateMetaKey(requestEvent.httpMethod, requestEvent.resource);
        console.trace('No method found for the ressource.', methodName);
        throw new MethodNotFoundError_1.default(`No method found for the ressource:${methodName}`);
    }
}
ControllerRegistry.controllersSet = new Set();
exports.default = ControllerRegistry;
//# sourceMappingURL=ControllerRegistry.js.map