"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Joi = require("joi");
const _ = require("lodash");
const ValidationError_1 = require("../exceptions/ValidationError");
class Validator {
    /**
     * Validate the field
     * @param validationSchema
     *  The validation Schema
     */
    static validateField(field, value, validationSchema) {
        const data = {};
        data[field] = value;
        const schema = {};
        schema[field] = validationSchema;
        this.validate(data, schema);
    }
    /**
     * Validate data using Joi
     * @param data
     * validation data
     * @param schema
     * the vailidate schema
     */
    static validate(data, schema) {
        const result = Joi.validate(data, schema, { abortEarly: false });
        if (result.error) {
            throw new ValidationError_1.default('Invalid data set', this.formatError(result.error.details));
        }
    }
    /**
     * Error message formatter
     * @param details
     *  The Details for the Error message
     * @return {{field: any, message: any}[]}
     */
    static formatError(details) {
        return _.map(details, (error) => {
            return { field: error['path'], message: error['message'] };
        });
    }
}
/**
 * Contains all Joi schemas for validation the properties for request
 */
Validator.VALIDATOR_SCHEMA = {
    UUID: Joi.string().uuid(),
    UUID_REQUIRED: Joi.string().uuid().required(),
    BOOK_STORE_NAME: Joi.string().required(),
    BOOK_STORE_ID: Joi.string().uuid().required(),
    IS_DELETED: Joi.boolean(),
    CREATED_DATE: Joi.string().isoDate(),
    LAST_MODIFIED: Joi.string().isoDate(),
};
exports.default = Validator;
//# sourceMappingURL=Validator.js.map